summaryrefslogtreecommitdiff
path: root/engine
diff options
context:
space:
mode:
Diffstat (limited to 'engine')
-rw-r--r--engine/battle/core.asm17
1 files changed, 9 insertions, 8 deletions
diff --git a/engine/battle/core.asm b/engine/battle/core.asm
index d944424e..5ea60cb4 100644
--- a/engine/battle/core.asm
+++ b/engine/battle/core.asm
@@ -2013,18 +2013,19 @@ DisplayBattleMenu::
.menuselected
ld [wTextBoxID], a
call DisplayTextBoxID
+ ; handle menu input if it's not the old man tutorial
ld a, [wBattleType]
dec a
- jp nz, .handleBattleMenuInput ; handle menu input if it's not the old man tutorial
+ jp nz, .handleBattleMenuInput
; the following happens for the old man tutorial
; Temporarily save the player name in wGrassRate,
; which is supposed to get overwritten when entering a
; map with wild Pokémon.
; Due to an oversight, the data may not get
; overwritten (on Cinnabar and Route 21) and the infamous
; Missingno. glitch can show up.
ld hl, wPlayerName
- ld de, wGrassRate
+ ld de, wLinkEnemyTrainerName
ld bc, NAME_LENGTH
call CopyData
ld hl, .oldManName
@@ -2013,18 +2013,19 @@ DisplayBattleMenu::
; the following happens for the old man tutorial
- ; Temporarily save the player name in wGrassRate,
- ; which is supposed to get overwritten when entering a
- ; map with wild Pokémon.
- ; Due to an oversight, the data may not get
- ; overwritten (on Cinnabar and Route 21) and the infamous
- ; Missingno. glitch can show up.
+ ; Temporarily save the player name in wLinkEnemyTrainerName.
+ ; Since wLinkEnemyTrainerName == wGrassRate, this affects wild encounters.
+ ; The wGrassRate byte and following wGrassMons buffer are supposed
+ ; to get overwritten when entering a map with wild Pokémon,
+ ; but an oversight prevents this in Cinnabar and Route 21,
+ ; so the infamous MissingNo. glitch can show up.
ld hl, wPlayerName